==> kbarcode-trinity-3.5.13.2.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/tec.h <==
//
// C++ Interface: tec
//
// Description: 
//
//
// Author: Dominik Seichter <domseichter@web.de>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef TEC_H
#define TEC_H
#include "dsmainwindow.h"
#include "labelutils.h"
#include "xmlutils.h"
#include "definition.h"
#include "batchiface.h"

// Other includes
#include <stdlib.h>
#include <stdio.h>

// QT includes
#include <tqclipboard.h>
#include <tqcursor.h>
#include <tqgroupbox.h>
#include <tqhbox.h>
#include <tqlayout.h>
#include <tqpainter.h>
#include <tqpaintdevicemetrics.h>
#include <tqprogressdialog.h>
#include <tqsqlcursor.h>
#include <tqvalidator.h>

// KDE includes
#include <kapplication.h>
#include <kcombobox.h>
#include <kfiledialog.h>
#include <kiconloader.h>
#include <klistview.h>
#include <klineedit.h>
#include <klineeditdlg.h>
#include <klocale.h>
#include <kmenubar.h>
#include <kmessagebox.h>
#include <kpopupmenu.h>
#include <knuminput.h>
#include <kprinter.h>
#include <kurlrequester.h>

TQString tec452(const TQString &file, int count, const TQString &art, const TQString &group, const TQString &id);
TQString convZeros( int count, int zeros );
TQString posConv( TQString str, int zeros );
int rotation (int valor);
TQString code39 (const TQDomElement &e, int countBar);
TQString code128 (const TQDomElement &e, int countBar);
TQString barcodeType(const TQString &type);
TQString withChecksum(const TQDomElement &e);
TQString sequence(const TQDomElement &e);
TQString serialWatch();
TQString pdf417 (const TQDomElement &e, int countBar);
TQString getData(const TQString &etext, const TQString &art, const TQString &group, const TQString &id);
TQString lineWidth(const TQDomElement &e);
TQString image (const TQString &file);
TQString getImage(const TQString &id);


#endif

==> kbarcode-trinity-14.1.5.tar.xz: kbarcode-trinity-14.1.5/kbarcode/tec.h <==
//
// C++ Interface: tec
//
// Description: 
//
//
// Author: Dominik Seichter <domseichter@web.de>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef TEC_H
#define TEC_H
#include "dsmainwindow.h"
#include "labelutils.h"
#include "xmlutils.h"
#include "definition.h"
#include "batchiface.h"

// Other includes
#include <stdlib.h>
#include <stdio.h>

// TQt includes
#include <tqclipboard.h>
#include <tqcursor.h>
#include <tqgroupbox.h>
#include <tqhbox.h>
#include <tqlayout.h>
#include <tqpainter.h>
#include <tqpaintdevicemetrics.h>
#include <tqprogressdialog.h>
#include <tqsqlcursor.h>
#include <tqvalidator.h>

// KDE includes
#include <tdeapplication.h>
#include <kcombobox.h>
#include <tdefiledialog.h>
#include <kiconloader.h>
#include <tdelistview.h>
#include <klineedit.h>
#include <klineeditdlg.h>
#include <tdelocale.h>
#include <tdemenubar.h>
#include <tdemessagebox.h>
#include <tdepopupmenu.h>
#include <knuminput.h>
#include <kprinter.h>
#include <kurlrequester.h>

TQString tec452(const TQString &file, int count, const TQString &art, const TQString &group, const TQString &id);
TQString convZeros( int count, int zeros );
TQString posConv( TQString str, int zeros );
int rotation (int valor);
TQString code39 (const TQDomElement &e, int countBar);
TQString code128 (const TQDomElement &e, int countBar);
TQString barcodeType(const TQString &type);
TQString withChecksum(const TQDomElement &e);
TQString sequence(const TQDomElement &e);
TQString serialWatch();
TQString pdf417 (const TQDomElement &e, int countBar);
TQString getData(const TQString &etext, const TQString &art, const TQString &group, const TQString &id);
TQString lineWidth(const TQDomElement &e);
TQString image (const TQString &file);
TQString getImage(const TQString &id);


#endif
